@@ -1,6 +1,7 @@
 from .algeria import Algeria
 from .benin import Benin
 from .ivory_coast import IvoryCoast
+from .kenya import Kenya
 from .madagascar import Madagascar
 from .sao_tome import SaoTomeAndPrincipe
 from .south_africa import SouthAfrica
@@ -11,6 +12,7 @@ __all__ = (
     'Algeria',
     'Benin',
     'IvoryCoast',
+    'Kenya',
     'Madagascar',
     'SaoTomeAndPrincipe',
     'SouthAfrica',
