@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Working day tools
 """
@@ -6,10 +5,7 @@ from copy import copy
 import warnings
 from calendar import monthrange
 from datetime import date, timedelta, datetime
-from math import pi
 
-import ephem
-import pytz
 from calverter import Calverter
 from dateutil import easter
 from lunardate import LunarDate
@@ -19,7 +15,7 @@ from .exceptions import UnsupportedDateType
 MON, TUE, WED, THU, FRI, SAT, SUN = range(7)
 
 
-class classproperty(object):
+class classproperty:
 
     def __init__(self, getter):
         self.getter = getter
@@ -46,7 +42,7 @@ def cleaned_date(day, keep_datetime=False):
     return day
 
 
-class Calendar(object):
+class Calendar:
 
     FIXED_HOLIDAYS = ()
     WEEKEND_DAYS = ()
@@ -317,7 +313,7 @@ class Calendar(object):
         day = day + timedelta(days=day_delta)
         return day
 
-    def get_working_days_delta(self, start, end):
+    def get_working_days_delta(self, start, end, include_start=False):
         """
         Return the number of working day between two given dates.
         The order of the dates provided doesn't matter.
@@ -338,6 +334,21 @@ class Calendar(object):
 
         This method should even work if your ``start`` and ``end`` arguments
         are datetimes.
+
+        By default, if the day after you start is not a working day,
+        the count will start at 0. If include_start is set to true,
+        this day will be taken into account.
+
+        Example:
+
+        >>> cal = France()
+        >>> day1 = parse('09/05/2018 00:01', dayfirst=True)
+        >>> day2 = parse('10/05/2018 19:01', dayfirst=True) # holiday in france
+        >>> cal.get_working_days_delta(day_1, day_2)
+        0
+
+        >>> cal.get_working_days_delta(day_1, day_2, include_start=True)
+        1
         """
         start = cleaned_date(start)
         end = cleaned_date(end)
@@ -347,8 +358,9 @@ class Calendar(object):
 
         if start > end:
             start, end = end, start
+
         # Starting count here
-        count = 0
+        count = 1 if include_start and self.is_working_day(start) else 0
         while start < end:
             start += timedelta(days=1)
             if self.is_working_day(start):
@@ -372,6 +384,7 @@ class ChristianMixin(Calendar):
     include_easter_sunday = False
     include_all_saints = False
     include_immaculate_conception = False
+    immaculate_conception_label = "Immaculate Conception"
     include_christmas = True
     include_christmas_eve = False
     include_ascension = False
@@ -456,7 +469,7 @@ class ChristianMixin(Calendar):
 
     def get_variable_days(self, year):  # noqa
         "Return the christian holidays list according to the mixin"
-        days = super(ChristianMixin, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         if self.include_epiphany:
             days.append((date(year, 1, 6), "Epiphany"))
         if self.include_clean_monday:
@@ -486,7 +499,7 @@ class ChristianMixin(Calendar):
         if self.include_all_souls:
             days.append((date(year, 11, 2), "All Souls Day"))
         if self.include_immaculate_conception:
-            days.append((date(year, 12, 8), "Immaculate Conception"))
+            days.append((date(year, 12, 8), self.immaculate_conception_label))
         if self.include_christmas:
             days.append((date(year, 12, 25), "Christmas Day"))
         if self.include_christmas_eve:
@@ -521,7 +534,7 @@ class WesternCalendar(Calendar):
     )
 
     def get_variable_days(self, year):
-        days = super(WesternCalendar, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         new_year = date(year, 1, 1)
         if self.shift_new_years_day:
             if new_year.weekday() in self.get_weekend_days():
@@ -632,7 +645,7 @@ class ChineseNewYearCalendar(LunarCalendar):
         return days
 
     def get_variable_days(self, year):
-        days = super(ChineseNewYearCalendar, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         days.extend(self.get_chinese_new_year(year))
         return days
 
@@ -654,7 +667,7 @@ class ChineseNewYearCalendar(LunarCalendar):
         falls on SUN.
         """
         # Unshifted days are here:
-        days = super(ChineseNewYearCalendar, self).get_calendar_holidays(year)
+        days = super().get_calendar_holidays(year)
         if self.shift_sunday_holidays:
             days_to_inspect = copy(days)
             for day_shifted in self.get_shifted_holidays(days_to_inspect):
@@ -662,70 +675,12 @@ class ChineseNewYearCalendar(LunarCalendar):
         return days
 
 
-class EphemMixin(LunarCalendar):
-    def calculate_equinoxes(self, year, timezone='UTC'):
-        """ calculate equinox with time zone """
-
-        tz = pytz.timezone(timezone)
-
-        d1 = ephem.next_equinox(str(year))
-        d = ephem.Date(str(d1))
-        equinox1 = d.datetime() + tz.utcoffset(d.datetime())
-
-        d2 = ephem.next_equinox(d1)
-        d = ephem.Date(str(d2))
-        equinox2 = d.datetime() + tz.utcoffset(d.datetime())
-
-        return (equinox1.date(), equinox2.date())
-
-    def solar_term(self, year, degrees, timezone='UTC'):
-        """
-        Returns the date of the solar term for the given longitude
-        and the given year.
-
-        Solar terms are used for Chinese and Taiwanese holidays
-        (e.g. Qingming Festival in Taiwan).
-
-        More information:
-        - https://en.wikipedia.org/wiki/Solar_term
-        - https://en.wikipedia.org/wiki/Qingming
-
-        This function is adapted from the following topic:
-        https://answers.launchpad.net/pyephem/+question/110832
-        """
-        twopi = 2 * pi
-        tz = pytz.timezone(timezone)
-
-        # Find out the sun's current longitude.
-
-        sun = ephem.Sun(ephem.Date(str(year)))
-        current_longitude = sun.hlong - pi
-
-        # Find approximately the right time of year.
-
-        target_longitude = degrees * ephem.degree
-        difference = (target_longitude - current_longitude) % twopi
-        t0 = ephem.Date(str(year)) + 365.25 * difference / twopi
-
-        # Zero in on the exact moment.
-
-        def f(t):
-            sun.compute(t)
-            longitude = sun.hlong - pi
-            return ephem.degrees(target_longitude - longitude).znorm
-
-        d = ephem.Date(ephem.newton(f, t0, t0 + ephem.minute))
-        solar_term = d.datetime() + tz.utcoffset(d.datetime())
-
-        return solar_term.date()
-
-
 class CalverterMixin(Calendar):
     conversion_method = None
     ISLAMIC_HOLIDAYS = ()
 
     def __init__(self, *args, **kwargs):
-        super(CalverterMixin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.calverter = Calverter()
         if self.conversion_method is None:
             raise NotImplementedError
@@ -752,20 +707,34 @@ class CalverterMixin(Calendar):
     def get_islamic_holidays(self):
         return self.ISLAMIC_HOLIDAYS
 
+    def get_delta_islamic_holidays(self, year):
+        """
+        Return the delta to add/substract according to the year or customs.
+
+        By default, to return None or timedelta(days=0)
+        """
+        return None
+
     def get_variable_days(self, year):
         warnings.warn('Please take note that, due to arbitrary decisions, '
                       'this Islamic calendar computation may be wrong.')
-        days = super(CalverterMixin, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         years = self.calverted_years(year)
         conversion_method = getattr(
             self.calverter, '%s_to_jd' % self.conversion_method)
         for month, day, label in self.get_islamic_holidays():
-                for y in years:
-                    jd = conversion_method(y, month, day)
-                    g_year, g_month, g_day = self.calverter.jd_to_gregorian(jd)
-                    if g_year == year:
-                        holiday = date(g_year, g_month, g_day)
-                        days.append((holiday, label))
+            for y in years:
+                jd = conversion_method(y, month, day)
+                g_year, g_month, g_day = self.calverter.jd_to_gregorian(jd)
+                holiday = date(g_year, g_month, g_day)
+
+                # Only add a delta if necessary
+                delta = self.get_delta_islamic_holidays(year)
+                if delta:
+                    holiday += delta
+
+                if holiday.year == year:
+                    days.append((holiday, label))
         return days
 
 
@@ -789,7 +758,7 @@ class IslamicMixin(CalverterMixin):
         """Return a list of Islamic (month, day, label) for islamic holidays.
         Please take note that these dates must be expressed using the Islamic
         Calendar"""
-        days = list(super(IslamicMixin, self).get_islamic_holidays())
+        days = list(super().get_islamic_holidays())
 
         if self.include_islamic_new_year:
             days.append((1, 1, "Islamic New Year"))
