@@ -1,15 +1,12 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 from datetime import timedelta
-from workalendar.core import WesternCalendar, ChristianMixin
-from workalendar.registry import iso_register
+from ..core import WesternCalendar, ChristianMixin
+from ..registry_tools import iso_register
 
 
 @iso_register('DK')
 class Denmark(WesternCalendar, ChristianMixin):
     'Denmark'
 
-    include_palm_sunday = True
     include_holy_thursday = True
     include_good_friday = True
     include_easter_sunday = True
@@ -23,16 +20,11 @@ class Denmark(WesternCalendar, ChristianMixin):
     boxing_day_label = "Second Day of Christmas"
     include_christmas_eve = True
 
-    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
-        (6, 5, "Constitution Day"),
-        (12, 31, "New Year's Eve")
-    )
-
     def get_store_bededag(self, year):  # 'great prayer day'
         easter_sunday = self.get_easter_sunday(year)
         return easter_sunday + timedelta(days=26)
 
     def get_variable_days(self, year):
-        days = super(Denmark, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         days.append((self.get_store_bededag(year), "Store Bededag"))
         return days
