@@ -4,12 +4,13 @@ from unittest import TestCase
 
 import pandas
 
-from workalendar.tests import GenericCalendarTest
-from workalendar.core import MON, TUE, THU, FRI, WED, SAT, SUN
-from workalendar.core import Calendar, LunarCalendar, WesternCalendar
-from workalendar.core import IslamicMixin, JalaliMixin, ChristianMixin
-from workalendar.core import EphemMixin
-from workalendar.exceptions import UnsupportedDateType
+from . import GenericCalendarTest
+from ..core import (
+    MON, TUE, THU, FRI, WED, SAT, SUN,
+    Calendar, LunarCalendar, WesternCalendar,
+    IslamicMixin, JalaliMixin, ChristianMixin
+)
+from ..exceptions import UnsupportedDateType
 
 
 class CalendarTest(GenericCalendarTest):
@@ -254,50 +255,6 @@ class JalaliMixinTest(GenericCalendarTest):
         self.assertEquals(len(days), 365)
 
 
-class EphemMixinTest(GenericCalendarTest):
-    cal_class = EphemMixin
-
-    def test_calculate_some_equinoxes(self):
-        self.assertEquals(
-            self.cal.calculate_equinoxes(2010),
-            (date(2010, 3, 20), date(2010, 9, 23))
-        )
-        self.assertEquals(
-            self.cal.calculate_equinoxes(2010, 'Asia/Taipei'),
-            (date(2010, 3, 21), date(2010, 9, 23))
-        )
-        self.assertEquals(
-            self.cal.calculate_equinoxes(2013),
-            (date(2013, 3, 20), date(2013, 9, 22))
-        )
-        self.assertEquals(
-            self.cal.calculate_equinoxes(2014),
-            (date(2014, 3, 20), date(2014, 9, 23))
-        )
-        self.assertEquals(
-            self.cal.calculate_equinoxes(2020),
-            (date(2020, 3, 20), date(2020, 9, 22))
-        )
-
-    def test_qingming_festivals(self):
-        self.assertEquals(
-            self.cal.solar_term(2001, 15),
-            date(2001, 4, 4)
-        )
-        self.assertEquals(
-            self.cal.solar_term(2001, 15, 'Asia/Taipei'),
-            date(2001, 4, 5)
-        )
-        self.assertEquals(
-            self.cal.solar_term(2011, 15),
-            date(2011, 4, 5)
-        )
-        self.assertEquals(
-            self.cal.solar_term(2014, 15),
-            date(2014, 4, 4)
-        )
-
-
 class MockChristianCalendar(WesternCalendar, ChristianMixin):
     pass
 
@@ -468,6 +425,20 @@ class WorkingDaysDeltatest(TestCase):
         delta = cal.get_working_days_delta(day2, day1)
         self.assertEqual(delta, 2)
 
+    def test_with_including_first_day(self):
+        # linked to #393
+        cal = MockChristianCalendar()
+        day1 = date(2018, 12, 24)  # December 24th: not holiday so working day
+        day2 = date(2018, 12, 25)  # December 25th: Christmas
+
+        # not including the first day, should return 0
+        delta = cal.get_working_days_delta(day1, day2)
+        self.assertEqual(delta, 0)
+
+        # including the first day, should return 1
+        delta = cal.get_working_days_delta(day1, day2, include_start=True)
+        self.assertEqual(delta, 1)
+
 
 class NoDocstring(Calendar):
     pass
