@@ -7,10 +7,19 @@ from ..europe import (
     Malta, Netherlands, Norway, Poland, Portugal, Romania, Russia, Slovakia,
     Slovenia, Spain,
     # Catalonia,  # TODO: Add it to registry
-    Sweden, Switzerland, Vaud, Geneva, UnitedKingdom,
+    Sweden, UnitedKingdom,
     UnitedKingdomNorthernIreland,
 )
 
+# Switzerland
+from ..europe import (
+    Switzerland,
+    Aargau, AppenzellInnerrhoden, AppenzellAusserrhoden, Bern, BaselLandschaft,
+    BaselStadt, Fribourg, Geneva, Glarus, Graubunden, Jura, Luzern, Neuchatel,
+    Nidwalden, Obwalden, StGallen, Schaffhausen, Solothurn, Schwyz, Thurgau,
+    Ticino, Uri, Vaud, Valais, Zug, Zurich
+)
+
 # Germany
 from ..europe import (
     Germany, BadenWurttemberg, Bavaria, Berlin, Brandenburg, Bremen,
@@ -31,6 +40,13 @@ GERMANY_REGION_CLASSES = (
     SaxonyAnhalt, SchleswigHolstein, Thuringia
 )
 
+SWITZERLAND_REGION_CLASSES = (
+    Aargau, AppenzellInnerrhoden, AppenzellAusserrhoden, Bern, BaselLandschaft,
+    BaselStadt, Fribourg, Geneva, Glarus, Graubunden, Jura, Luzern, Neuchatel,
+    Nidwalden, Obwalden, StGallen, Schaffhausen, Solothurn, Schwyz, Thurgau,
+    Ticino, Uri, Vaud, Valais, Zug, Zurich
+)
+
 
 class RegistryEurope(TestCase):
     def test_europe(self):
@@ -72,6 +88,8 @@ class RegistryEurope(TestCase):
         self.assertIn(Germany, classes)
         for klass in GERMANY_REGION_CLASSES:
             self.assertIn(klass, classes)
+        for klass in SWITZERLAND_REGION_CLASSES:
+            self.assertIn(klass, classes)
 
     def test_germany_subregion(self):
         # Get all the subregions
@@ -80,6 +98,13 @@ class RegistryEurope(TestCase):
         for klass in GERMANY_REGION_CLASSES:
             self.assertIn(klass, classes)
 
+    def test_switzerland_subregion(self):
+        # Get all the subregions
+        classes = (v for k, v in registry.get_subregions('CH').items())
+        classes = list(classes)
+        for klass in SWITZERLAND_REGION_CLASSES:
+            self.assertIn(klass, classes)
+
     def test_slovenia_code(self):
         # Source: https://github.com/peopledoc/workalendar/pull/291
         self.assertEqual(registry.region_registry['SI'], Slovenia)
