@@ -1,10 +1,6 @@
-# -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 from .core import UnitedStates
 from ..core import MON
-from ..registry import iso_register
+from ..registry_tools import iso_register
 
 
 @iso_register('US-AL')
@@ -15,20 +11,7 @@ class Alabama(UnitedStates):
     presidents_day_label = "George Washington/Thomas Jefferson Birthday"
     columbus_day_label = ("Columbus Day / Fraternal Day /"
                           " American Indian Heritage Day")
-
-    def get_jefferson_davis_birthday(self, year):
-        """
-        The first MON of June is Jefferson Davis Birthday
-        """
-        return (
-            self.get_nth_weekday_in_month(year, 6, MON, 1),
-            "Jefferson Davis Birthday"
-        )
-
-    def get_variable_days(self, year):
-        days = super(Alabama, self).get_variable_days(year)
-        days.append(self.get_jefferson_davis_birthday(year))
-        return days
+    include_jefferson_davis_birthday = True
 
 
 class AlabamaBaldwinCounty(Alabama):
@@ -54,6 +37,6 @@ class AlabamaPerryCounty(Alabama):
         )
 
     def get_variable_days(self, year):
-        days = super(AlabamaPerryCounty, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         days.append(self.get_obama_day(year))
         return days
