@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 from datetime import date, timedelta
 
 from ..core import WesternCalendar, ChristianMixin
 from ..core import SUN, MON, TUE, WED, THU, FRI, SAT
-from ..registry import iso_register
+from ..registry_tools import iso_register
 
 
 @iso_register('US')
@@ -36,6 +32,8 @@ class UnitedStates(WesternCalendar, ChristianMixin):
     columbus_day_label = "Columbus Day"
     # Confederation day
     include_confederation_day = False
+    # Jefferson Davis Birthday.
+    include_jefferson_davis_birthday = False
 
     # Include Cesar Chavez day(s)
     include_cesar_chavez_day = False
@@ -103,10 +101,18 @@ class UnitedStates(WesternCalendar, ChristianMixin):
         if christmas_eve in holiday_lookup:
             # You are observing the THU before, as an extra XMas Eve
             if christmas.weekday() == SAT:
+                # Remove the "fake" XMAS Day shift, the one done before.
+                new_holidays.remove(
+                    (christmas_eve, "Christmas Day (Observed)")
+                )
                 new_holidays.append((date(year, 12, 23),
                                      "Christmas Eve (Observed)"))
-            # You are observing the 26th (TUE) and 27th (WED)
+            # You are observing the 26th (TUE)
             elif christmas.weekday() == MON:
+                # Remove the "fake" XMAS Eve shift, done before
+                new_holidays.remove(
+                    (christmas, "Christmas Eve (Observed)")
+                )
                 new_holidays.append((date(year, 12, 26),
                                      "Christmas Day (Observed)"))
         return holidays + new_holidays
@@ -134,19 +140,29 @@ class UnitedStates(WesternCalendar, ChristianMixin):
         return (self.get_election_date(year), self.election_day_label)
 
     def get_thanksgiving_friday(self, year):
-        "Thanksgiving friday is on the 4th Friday in November"
-        return (
-            self.get_nth_weekday_in_month(year, 11, FRI, 4),
-            self.thanksgiving_friday_label
-        )
+        """
+        Thanksgiving friday is on the day following Thanksgiving Day
+        """
+        thanksgiving = UnitedStates.get_nth_weekday_in_month(year, 11, THU, 4)
+        thanksgiving_friday = thanksgiving + timedelta(days=1)
+        return (thanksgiving_friday, self.thanksgiving_friday_label)
 
     def get_confederate_day(self, year):
         """
-        Confederation memorial day is on the 4th MON of April.
+        Confederate memorial day is on the 4th MON of April.
         """
         day = self.get_nth_weekday_in_month(year, 4, MON, 4)
         return (day, "Confederate Memorial Day")
 
+    def get_jefferson_davis_birthday(self, year):
+        """
+        The first MON of June is Jefferson Davis Birthday
+        """
+        return (
+            self.get_nth_weekday_in_month(year, 6, MON, 1),
+            "Jefferson Davis Birthday"
+        )
+
     def get_martin_luther_king_date(self, year):
         """
         Martin Luther King is on 3rd MON of January, starting of 1985.
@@ -265,7 +281,7 @@ class UnitedStates(WesternCalendar, ChristianMixin):
 
     def get_variable_days(self, year):
         # usual variable days
-        days = super(UnitedStates, self).get_variable_days(year)
+        days = super().get_variable_days(year)
 
         # Martin Luther King's Day started only in 1985
         if year >= 1985:
@@ -300,6 +316,9 @@ class UnitedStates(WesternCalendar, ChristianMixin):
         if self.include_confederation_day:
             days.append(self.get_confederate_day(year))
 
+        if self.include_jefferson_davis_birthday:
+            days.append(self.get_jefferson_davis_birthday(year))
+
         if self.include_inauguration_day:
             # Is it a "Inauguration year"?
             if UnitedStates.is_presidential_year(year - 1):
@@ -329,7 +348,7 @@ class UnitedStates(WesternCalendar, ChristianMixin):
         return (date(year, 11, 11), self.veterans_day_label)
 
     def get_fixed_holidays(self, year):
-        days = super(UnitedStates, self).get_fixed_holidays(year)
+        days = super().get_fixed_holidays(year)
         if self.include_veterans_day:
             days.append(self.get_veterans_day(year))
         return days
@@ -338,6 +357,6 @@ class UnitedStates(WesternCalendar, ChristianMixin):
         """
         Will return holidays and their shifted days
         """
-        days = super(UnitedStates, self).get_calendar_holidays(year)
+        days = super().get_calendar_holidays(year)
         days = self.shift(days, year)
         return days
